import type { FormItemRule, GridItemProps, GridProps, TooltipProps } from "naive-ui";
import { ExtractThemeOverrides } from "naive-ui/es/_mixins/use-theme";
import { GlobalThemeWithoutCommon } from "naive-ui/es/config-provider/src/internal-interface";
import { Theme } from "naive-ui/es/_mixins/use-theme";
import type { CSSProperties, Component, VNode } from "vue";
import type { FormActionType } from "./formAction";
import type { VNodeChild } from "vue";
export interface FormProps {
    modelValueName?: string;
    model?: Record<string, any>;
    showLabel?: boolean;
    labelWidth?: number | string | "auto";
    labelAlign?: import("./Rule").LabelAlign;
    labelPlacement?: import("./Rule").LabelPlacement;
    colon?: string;
    schemas?: FormSchema[];
    inline?: boolean;
    layout?: string;
    size?: import("./Rule").FormSize;
    canCollapse?: boolean;
    collapsedRows?: number;
    collapsed?: boolean;
    showActions?: boolean;
    actionGridProps?: Omit<GridItemProps, "collapsed" | "collapsedRows">;
    gridProps?: Omit<GridProps, "collapsed" | "collapsedRows">;
    baseGridStyle?: CSSProperties;
    showRequireMark?: boolean;
    requireMarkPlacement?: import("./Rule").RequiredMarkPlacement;
    validateMessages?: any;
    loading?: boolean;
    disabled?: boolean;
    rules?: {
        [schemaField: string]: FormItemRule | FormItemRule[];
    };
    breakpoints?: {
        [screenWidth: string]: number;
    };
    themeOverrides?: ExtractThemeOverrides<Theme<Pick<GlobalThemeWithoutCommon, "Form">, {
        blankHeightSmall: string;
        blankHeightMedium: string;
        blankHeightLarge: string;
        lineHeight: string;
        labelTextColor: string;
        asteriskColor: string;
        feedbackTextColorError: string;
        feedbackTextColorWarning: string;
        feedbackTextColor: string;
        feedbackPadding: string;
        feedbackHeightSmall: string;
        feedbackHeightMedium: string;
        feedbackHeightLarge: string;
        feedbackFontSizeSmall: string;
        feedbackFontSizeMedium: string;
        feedbackFontSizeLarge: string;
        labelFontSizeLeftSmall: string;
        labelFontSizeLeftMedium: string;
        labelFontSizeLeftLarge: string;
        labelFontSizeTopSmall: string;
        labelFontSizeTopMedium: string;
        labelFontSizeTopLarge: string;
        labelHeightSmall: string;
        labelHeightMedium: string;
        labelHeightLarge: string;
        labelPaddingVertical: string;
        labelPaddingHorizontal: string;
        labelTextAlignVertical: string;
        labelTextAlignHorizontal: string;
        labelFontWeight: string;
    }>>;
}
export type Return<Args = undefined, Result = string | VNode> = (arg: Args) => Result;
export type SchemaCallParams = {
    model: Readonly<Record<string, any>>;
    readonly field: string;
    readonly values: Readonly<Record<string, any>>;
    readonly action: FormActionType;
    readonly schema: FormSchema;
};
export type SchemaFunctionalCall<Params = SchemaCallParams, Render = VNode, ExtraArg = any> = (params: Params, ...args: ExtraArg[]) => Render;
export interface FormSchema<ComponentType = string, DefaultValue = unknown, ComponentProps = Record<string, any>> {
    modelValueName?: string;
    field: string;
    label?: string | Return<{
        colon?: string;
    }, VNode | VNodeChild>;
    labelWidth?: number | string | "auto";
    labelAlign?: import("./Rule").LabelAlign;
    labelPlacement?: import("./Rule").LabelPlacement;
    helpMessage?: string;
    helpMessageToolTipProps?: TooltipProps;
    helpMessageIcon?: Return<undefined, VNode>;
    helpMessageIconProps?: CSSProperties & Record<string, any>;
    defaultValue?: DefaultValue;
    component: ComponentType;
    componentProps?: ComponentProps | SchemaFunctionalCall<SchemaCallParams, ComponentProps>;
    rule?: FormItemRule | FormItemRule[];
    colProps?: GridItemProps;
    size?: import("./Rule").FormSize;
    ifShow?: boolean | SchemaFunctionalCall<Pick<SchemaCallParams, "values" | "field">, boolean>;
    show?: boolean | SchemaFunctionalCall<Pick<SchemaCallParams, "values" | "field">, boolean>;
    contentRender?: SchemaFunctionalCall<SchemaCallParams & {
        Grid: Component;
        FormItem: Component;
    }, VNode | string>;
    slot?: string;
    feedback?: string;
    first?: boolean;
    validationStatus?: import("./Rule").ValidateStatus;
}
export type SetFormValue = <T = any>(key: string, value: T) => {
    key: string;
    value: T;
    values: Record<string, any>;
};
export type FormContext = {
    formModel: Record<string, any>;
    values: Readonly<Record<string, any>>;
    schemas: FormSchema[];
    action: FormActionType;
};
export type EmitTypes = (event: "register" | "schema-change" | "validate-error" | "submit" | "collapse-change" | "reset" | "clear-validate", ...args: any[]) => void;
